@@ -10,12 +10,13 @@ import traceback
 from ipykernel.kernelbase import Kernel
 from ipykernel.kernelapp import IPKernelApp
 import mysql.connector
-#import signal
+
+# import signal
 
 str_kernel = "sqlmk"
-__version__ = "0.1.3"
+__version__ = "0.1.4"
 
-DEBUG = 1
+DEBUG = 0
 
 
 def log(str):
@@ -82,7 +83,7 @@ class DBConnection:
                     cur.execute(qry)
                 except Exception as e:
                     self.con.rollback()
-                    rows=[[str(e)]]
+                    rows = [[str(e)]]
                     log("-- QUERY EXECUTION ERROR: " + str(e))
                     error_ind = True
                 # TRY TO FETCH DATA
@@ -93,14 +94,14 @@ class DBConnection:
                 except Exception as e:
                     log("-- NO FETCH : " + str(e))
                 # COMMIT WHEN NO ERROR IS PRESENT
-                #log("-- COMMIT YN: " + str(error_ind) + " " + str(data_ind))
+                # log("-- COMMIT YN: " + str(error_ind) + " " + str(data_ind))
                 if error_ind is False:
                     self.con.commit()
                 if error_ind is False and data_ind is False:
-                    rows=[["OK"]]
+                    rows = [["OK"]]
                 # IF DATA AND NO ERROR GET HEADER
                 if data_ind is True and cur.description:
-                    #log(str(rows))
+                    # log(str(rows))
                     for cn in cur.description:
                         hdr.append(cn[0])
                     df.append(hdr)
@@ -133,12 +134,13 @@ class DBConnection:
     def __del__(self):
         self.disconnect()
 
+
 class SQLmKernel(Kernel):
 
     implementation = str_kernel
     implementation_version = __version__
     dbcon = None
-    #html_output = True
+    # html_output = True
     html_output = False
 
     con = None
@@ -150,7 +152,6 @@ class SQLmKernel(Kernel):
         "password": "",
     }
 
-
     @property
     def language_version(self):
         return ""
@@ -159,22 +160,21 @@ class SQLmKernel(Kernel):
     def banner(self):
         return ""
 
-    #@property
-    #def files(self):
+    # @property
+    # def files(self):
     #    return ""
 
-    #@property
-    #def master_path(self):
+    # @property
+    # def master_path(self):
     #    return ""
 
-
     language_info = {
         "name": str_kernel,
         "mimetype": "text/plain",
         "file_extension": ".sql",
     }
 
-    #def handler(signum, frame):
+    # def handler(signum, frame):
     #    log("- - - - - - - - - - - - - SIGINT || SIGTERM")
 
     def __init__(self, **kwargs):
@@ -183,18 +183,21 @@ class SQLmKernel(Kernel):
             self.dbcon = self.constr
             self.con = DBConnection(self.dbcon)
             log("__init__")
-            #self.html_output = True
+            # self.html_output = True
             self.html_output = False
         except Exception as e:
             log("-- KERNEL INIT PROBLEM: " + str(e))
             log(traceback.format_exc())
-        #signal.signal(signal.SIGINT, self.handler)
-        #signal.signal(signal.SIGTERM, self.handler)
+        # signal.signal(signal.SIGINT, self.handler)
+        # signal.signal(signal.SIGTERM, self.handler)
 
-    def send_message_html(self, html ):
+    def send_message_html(self, html):
         try:
-            message = {"data": { "text/html": html }, "metadata": {}, }
-            #message = {"data": { "text/plain": html }, "metadata": {}, }
+            message = {
+                "data": {"text/html": html},
+                "metadata": {},
+            }
+            # message = {"data": { "text/plain": html }, "metadata": {}, }
             self.send_response(self.iopub_socket, "display_data", message)
             return {
                 "status": "ok",
@@ -224,33 +227,33 @@ class SQLmKernel(Kernel):
         msg = ""
         try:
             if self.con.cols and self.con.rows:
-                 msg = "<table>"
-                 for row in res:
-                     msg += "<tr>"
-                     for cell in row:
-                         msg += "<td>" + str(cell) +"</td>"
-                     msg += "</tr>"
-                 msg += "</table>"
+                msg = "<table>"
+                for row in res:
+                    msg += "<tr>"
+                    for cell in row:
+                        msg += "<td>" + str(cell) + "</td>"
+                    msg += "</tr>"
+                msg += "</table>"
             else:
                 msg = "No data"
         except Exception as e:
             log("-- CONV DATA TO HTML ERROR: " + str(e))
             log(traceback.format_exc())
 
-        return(msg)
+        return msg
 
     def save_data_to_csv(self, file_name):
-        msg=None
+        msg = None
         if self.con.cols and self.con.rows:
-             try:
-                 with open(file_name+'.csv','w') as out:
-                     csv_out = csv.writer(out)
-                     csv_out.writerow(self.con.cols)
-                     for row in self.con.rows:
-                         csv_out.writerow(row)
-                     msg = "Written "+file_name+".csv"
-             except Exception as e:
-                 msg="Error during csv export "+str(e)
+            try:
+                with open(file_name + ".csv", "w") as out:
+                    csv_out = csv.writer(out)
+                    csv_out.writerow(self.con.cols)
+                    for row in self.con.rows:
+                        csv_out.writerow(row)
+                    msg = "Written " + file_name + ".csv"
+            except Exception as e:
+                msg = "Error during csv export " + str(e)
         else:
             msg = "No data to save"
         self.send_message(msg)
@@ -277,7 +280,7 @@ class SQLmKernel(Kernel):
                     if magics["dbcon"]:
                         self.dbcon = str(magics["dbcon"])
                         self.constr = self.dbcon
-                        #log(str(self.dbcon))
+                        # log(str(self.dbcon))
                     else:
                         # status, res = self.con.qry2df(code, self.constr)
                         status, res = self.con.qry2df(code)
@@ -314,13 +317,13 @@ class SQLmKernel(Kernel):
                     # log("-- dbconln magics: " + dbconln[0:5])
                     if dbconln[0:5] == "dbcon":
                         if len(dbconln) > 6:
-                              magics["dbcon"] = dbconln[6:]
-                              self.dbcon = json.loads(magics["dbcon"])
-                              self.constr = self.dbcon
-                              log("-- TYRING TO CONNECT WITH: " + str(self.constr))
-                              conret = self.con.connect(self.constr)
-                              log("-- MAGICS DBCON CONNECTED: " + str(self.con.connected))
-                              self.send_message(conret)
+                            magics["dbcon"] = dbconln[6:]
+                            self.dbcon = json.loads(magics["dbcon"])
+                            self.constr = self.dbcon
+                            log("-- TYRING TO CONNECT WITH: " + str(self.constr))
+                            conret = self.con.connect(self.constr)
+                            log("-- MAGICS DBCON CONNECTED: " + str(self.con.connected))
+                            self.send_message(conret)
                     elif dbconln[0:5] == "otext":
                         self.html_output = False
                         self.send_message("Output mode set to text")
@@ -332,10 +335,10 @@ class SQLmKernel(Kernel):
                         log("-- OUTPUT MODE HTML")
                         magics["noexec"] = True
                     elif dbconln[0:5] == "dsave":
-                        fname="tmp"
+                        fname = "tmp"
                         if len(dbconln) > 6:
-                            fname = dbconln[6:] 
-                        log("-- SAVING DATA TO FILE")       
+                            fname = dbconln[6:]
+                        log("-- SAVING DATA TO FILE")
                         self.save_data_to_csv(fname)
                         magics["noexec"] = True
                     elif dbconln[0:5] == "csave":
@@ -375,4 +378,5 @@ class SQLmKernel(Kernel):
             os.remove(file)
         os.remove(self.master_path)
 
+
 IPKernelApp.launch_instance(kernel_class=SQLmKernel)
